==> haskell-yaml-0.11.11.2-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-8e5unmrXdnl2ZPxT6bSVG7
key:                  yaml-0.11.11.2-8e5unmrXdnl2ZPxT6bSVG7
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  342489dbb9da991701711aa9295bd836
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-8e5unmrXdnl2ZPxT6bSVG7
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    attoparsec-0.14.4-8RYxJQa7MEjKmC3I11Us4k base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-xf7BUYu4FPC4jaCDr8wkD
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-LIMOu11DF4wGi80O1xBEiY mtl-2.2.2
    resourcet-1.2.6-223TkNfardcC3p5LC28WLD
    scientific-0.3.7.0-BkypiqTAkpN3suN2c81wMx template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX
    vector-0.13.1.0-D9au4GPCsbT1DKgXASrr5O

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-FScUm9gyt7PLlYDEwBPwqI
key:                  yaml-0.11.11.2-FScUm9gyt7PLlYDEwBPwqI
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  1ad713d1a743d489932fb7f9f3dfb6a6
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-FScUm9gyt7PLlYDEwBPwqI
depends:
    aeson-2.1.2.1-Ex7WnNUT1auEGSF1Md5zyM
    attoparsec-0.14.4-4lxImiie977LVZ07Q4RuOa base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-IZ8OSXmnRyPK1N2pz1JDDM
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-8U4oXg3OkCx26LWZW4dpGl mtl-2.2.2
    resourcet-1.2.6-IGynvl9svIK6TArSccG3vI
    scientific-0.3.7.0-CCWbwGLTUrCAfmDn1czSkZ template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-EFINKuAnn2VCsrMAVqSNI6
    vector-0.13.1.0-KSX0XQMPS0MKwOGi5hYJAY

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
